%define pypi_name pycurl

# we don't want to provide private python extension libs
%global __provides_exclude_from ^(%{python3_sitearch}/.*\\.so)$

Summary:       A Python interface to libcurl
Name:          python-curl
Version:       7.44.1
Release:       %mkrel 3
Group:         Development/Python
License:       LGPLv2+
URL:           http://pycurl.sourceforge.net
Source0:       %{pypi_source}
Patch0:        pycurl-7.44.1-link.patch
# drop link-time vs. run-time TLS backend check (#1446850)
Patch2:         0002-python-pycurl-7.43.0-tls-backend.patch
BuildRequires: pkgconfig(python3)
BuildRequires: pkgconfig(libcurl) >= 7.21.5
BuildRequires: pkgconfig(openssl)

%description
PycURL is a Python interface to libcurl. PycURL can be used to fetch
objects identified by a URL from a Python program, similar to the
urllib Python module. PycURL is mature, very fast, and supports a lot
of features.

%package -n python3-curl
Summary:       A Python 3 interface to libcurl
Group:         Development/Python
Provides:      python3-pycurl = %{version}-%{release}

%description -n python3-curl
PycURL is a Python3 interface to libcurl. PycURL can be used to fetch
objects identified by a URL from a Python program, similar to the
urllib Python module. PycURL is mature, very fast, and supports a lot
of features.

%prep
%autosetup -p1 -n %{pypi_name}-%{version}

%py3_shebang_fix setup.py

%build
%{__python3} setup.py docstrings
%py3_build -- --with-openssl

%check
export PYTHONPATH=$RPM_BUILD_ROOT%{python3_sitearch}
%{__python3} -c 'import %{pypi_name}; print(%{pypi_name}.version)'

%install
export PYCURL_SSL_LIBRARY=openssl
%py3_install -- --with-openssl

rm -rf %{buildroot}%{_datadir}/doc/pycurl


%files -n python3-curl
%doc COPYING-LGPL COPYING-MIT ChangeLog README.rst examples doc
%{python3_sitearch}/*



%changelog
* Wed Mar 23 2022 umeabot <umeabot> 7.44.1-3.mga9
+ Revision: 1822290
- Mageia 9 Mass Rebuild

* Fri Feb 11 2022 wally <wally> 7.44.1-2.mga9
+ Revision: 1772925
- rebuild for python3.10

* Tue Jan 04 2022 wally <wally> 7.44.1-1.mga9
+ Revision: 1766875
- new version 7.44.1

* Sat Oct 02 2021 wally <wally> 7.43.0.2-6.mga9
+ Revision: 1747802
- rebuild for openssl 3.0.0

* Tue Mar 16 2021 tmb <tmb> 7.43.0.2-5.mga9
+ Revision: 1703839
- rebuild for python 3.9

* Sun Feb 16 2020 umeabot <umeabot> 7.43.0.2-4.mga8
+ Revision: 1531810
- Mageia 8 Mass Rebuild

* Sun Sep 15 2019 tv <tv> 7.43.0.2-3.mga8
+ Revision: 1441035
- drop now useless patch

* Wed Sep 11 2019 tv <tv> 7.43.0.2-2.mga8
+ Revision: 1439693
- patch 0: fix building with python-3.8
- rebuild for python-3.8
- drop python2 subpkg

* Mon Jan 14 2019 luigiwalser <luigiwalser> 7.43.0.2-1.mga7
+ Revision: 1356237
- 7.43.0.2

* Mon Jan 07 2019 wally <wally> 7.43.0.1-3.mga7
+ Revision: 1350897
- rebuild for python3.7

* Sun Sep 23 2018 umeabot <umeabot> 7.43.0.1-2.mga7
+ Revision: 1300465
- Mageia 7 Mass Rebuild

* Tue Apr 24 2018 daviddavid <daviddavid> 7.43.0.1-1.mga7
+ Revision: 1222175
- new version: 7.43.0.1

* Tue Apr 24 2018 daviddavid <daviddavid> 7.43.0-4.mga7
+ Revision: 1222162
- rename python-curl to python2-curl
- use new python macros

* Fri Aug 04 2017 tv <tv> 7.43.0-3.mga7
+ Revision: 1134536
- rebuild for new python

* Sun May 14 2017 ngompa <ngompa> 7.43.0-2.mga6
+ Revision: 1100989
- Add missing python2-(curl|pycurl) and python3-pycurl Provides
- Update Provides filtering rule to use standard RPM one

* Thu May 12 2016 philippem <philippem> 7.43.0-1.mga6
+ Revision: 1014388
- update to 7.43.0

* Tue Feb 16 2016 umeabot <umeabot> 7.19.5.3-2.mga6
+ Revision: 962200
- Mageia 6 Mass Rebuild

* Thu Nov 05 2015 philippem <philippem> 7.19.5.3-1.mga6
+ Revision: 897985
- update to 7.19.5.3

* Wed Oct 07 2015 tv <tv> 7.19.5-5.mga6
+ Revision: 886698
- rebuild for python 3.5

* Wed Oct 15 2014 umeabot <umeabot> 7.19.5-4.mga5
+ Revision: 746397
- Second Mageia 5 Mass Rebuild

* Sat Sep 27 2014 tv <tv> 7.19.5-3.mga5
+ Revision: 728215
- rebuild for missing pythoneggs deps

* Tue Sep 16 2014 umeabot <umeabot> 7.19.5-2.mga5
+ Revision: 687954
- Mageia 5 Mass Rebuild

* Sun Jul 27 2014 philippem <philippem> 7.19.5-1.mga5
+ Revision: 657635
- update to 7.19.5, add Python3
+ pterjan <pterjan>
- Rebuild for new Python

* Tue Oct 22 2013 umeabot <umeabot> 7.19.0-10.mga4
+ Revision: 543173
- Mageia 4 Mass Rebuild

* Tue Oct 15 2013 pterjan <pterjan> 7.19.0-9.mga4
+ Revision: 498337
- Rebuild to add different pythonegg provides for python 2 and 3

* Sun Jan 13 2013 umeabot <umeabot> 7.19.0-8.mga3
+ Revision: 378626
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild

* Wed Dec 12 2012 fwang <fwang> 7.19.0-7.mga3
+ Revision: 329949
- fix linkage
- fix linkage
- fix linkage

* Thu Feb 17 2011 dmorgan <dmorgan> 7.19.0-6.mga1
+ Revision: 53056
- imported package python-curl


* Fri Oct 29 2010 Michael Scherer <misc@mandriva.org> 7.19.0-6mdv2011.0
+ Revision: 589994
- rebuild for python 2.7

* Mon Apr 12 2010 Funda Wang <fwang@mandriva.org> 7.19.0-5mdv2010.1
+ Revision: 533669
- rebuild for openssl 1.0

* Sun Oct 11 2009 Funda Wang <fwang@mandriva.org> 7.19.0-4mdv2010.0
+ Revision: 456652
- provides python-pycurl

* Tue Sep 15 2009 Thierry Vignaud <tv@mandriva.org> 7.19.0-3mdv2010.0
+ Revision: 442090
- rebuild

* Fri Dec 26 2008 Adam Williamson <awilliamson@mandriva.org> 7.19.0-2mdv2009.1
+ Revision: 319516
- rebuild with python 2.6

* Sun Sep 14 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 7.19.0-1mdv2009.0
+ Revision: 284779
- new release

* Wed Sep 10 2008 Per Øyvind Karlsen <peroyvind@mandriva.org> 7.18.2-1mdv2009.0
+ Revision: 283580
- new release

* Fri Aug 01 2008 Thierry Vignaud <tv@mandriva.org> 7.16.4-5mdv2009.0
+ Revision: 259529
- rebuild

* Thu Jul 24 2008 Thierry Vignaud <tv@mandriva.org> 7.16.4-4mdv2009.0
+ Revision: 247398
- rebuild

* Fri Dec 21 2007 Olivier Blin <oblin@mandriva.com> 7.16.4-2mdv2008.1
+ Revision: 136447
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Sep 14 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 7.16.4-2mdv2008.0
+ Revision: 85589
- rework spec file
  add checks
  tune up CFLAGS

  + Götz Waschk <waschk@mandriva.org>
    - fix license

* Thu Sep 06 2007 Götz Waschk <waschk@mandriva.org> 7.16.4-1mdv2008.0
+ Revision: 80680
- new version
- update license tag


* Wed Nov 29 2006 Götz Waschk <waschk@mandriva.org> 7.15.5.1-1.20061108.1mdv2007.0
+ Revision: 88787
- Import python-curl

* Wed Nov 29 2006 Götz Waschk <waschk@mandriva.org> 7.15.5.1-1.20061108.1mdv2007.1
- cvs snapshot

* Tue May 03 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 7.13.2-2mdk
- BuildRequires : need recent curl

* Tue May 03 2005 Rafael Garcia-Suarez <rgarciasuarez@mandriva.com> 7.13.2-1mdk
- 7.13.2

* Sat Dec 04 2004 Michael Scherer <misc@mandrake.org> 7.12.2-2mdk
- Rebuild for new python

* Tue Nov 23 2004 Götz Waschk <waschk@linux-mandrake.com> 7.12.2-1mdk
- initial package

